﻿from azure.identity import DefaultAzureCredential
from azure.mgmt.media import AzureMediaServices
from azure.mgmt.media.models import (
    Asset,
    Transform,
    TransformOutput,
    BuiltInStandardEncoderPreset,
    Job,
    JobInputAsset,	
    JobOutputAsset
)

# Azure subscription details
subscription_id = '8f2a53ee-ae05-419b-8e1d-017fb2195104'
resource_group_name = 'azureencoder'
account_name = 'azurepaygoencodwr'

# Initialize Azure Media Services client
credential = DefaultAzureCredential()
client = AzureMediaServices(credential, subscription_id)

# Create or update an asset
asset_name = "drivescedoo"
asset = client.assets.create_or_update(resource_group_name, account_name, asset_name, Asset())

# Create or update a transform
transform_name = "MyTransform"
outputs = [
    TransformOutput(
        preset=BuiltInStandardEncoderPreset(
            preset_name="AdaptiveStreaming"  # Adaptive streaming preset
        )
    )
]
client.transforms.create_or_update(resource_group_name, account_name, transform_name, outputs)

# Create a job
job_name = "MyEncodingJob"
input_asset = JobInputAsset(asset_name=asset_name)
output_asset_720p = JobOutputAsset(asset_name=f"{asset_name}_720p")
output_asset_480p = JobOutputAsset(asset_name=f"{asset_name}_480p")
output_asset_360p = JobOutputAsset(asset_name=f"{asset_name}_360p")
job = Job(input=input_asset, outputs=[output_asset_720p, output_asset_480p, output_asset_360p])

client.jobs.create(resource_group_name, account_name, transform_name, job_name, job)

# Retrieve the locator (URL) for each encoded asset
locator_720p = client.assets.list_container_sas(
    resource_group_name, account_name, output_asset_720p.asset_name, permissions="Read", expiry_time="2023-12-31"
).asset_container_sas_urls[0]
locator_480p = client.assets.list_container_sas(
    resource_group_name, account_name, output_asset_480p.asset_name, permissions="Read", expiry_time="2023-12-31"
).asset_container_sas_urls[0]
locator_360p = client.assets.list_container_sas(
    resource_group_name, account_name, output_asset_360p.asset_name, permissions="Read", expiry_time="2023-12-31"
).asset_container_sas_urls[0]

print("720p Quality URL:", locator_720p)
print("480p Quality URL:", locator_480p)
print("360p Quality URL:", locator_360p)